BuildChild class

Custom class to build element

Constructors

BuildChild({required Widget tmpWidget, required double currentSize, required double maxWidth, required double currentCounter, required List<Widget> tmpChildren, required List<Row> finals})

Properties

currentCounter ↔ double
The current counter for the current width
getter/setter pair
currentSize → double
The current size
final
finals ↔ List<Row>
The finals row to append inside the responsive widget
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxWidth → double
The max width of the row
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tmpChildren ↔ List<Widget>
The tmp children list
getter/setter pair
tmpWidget → Widget
The tmp widget to add inside this responsive child
final

Methods

buildChild() → void
It builds the responsive child
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited