Generic class

Generic class to check generic devices

Constructors

Generic({required int maxWith})

Properties

extraLarge ↔ GenericDevice
ExtraLarge sizes
getter/setter pair
extraSmall ↔ GenericDevice
ExtraSmall sizes
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
large ↔ GenericDevice
Large sizes
getter/setter pair
maxWith → int
The max width of the current device
final
medium ↔ GenericDevice
Medium sizes
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
small ↔ GenericDevice
Small sizes
getter/setter pair

Methods

deviceType() → int
Check which device type is
isExtraLarge() → bool
Check if is an extra large device
isExtraSmall() → bool
Check if is an extra small device
isLarge() → bool
Check if is a large device
isMedium() → bool
Check if is a medium device
isSmall() → bool
Check if is a small device
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited